@@ -49,6 +49,9 @@ import Data.Traversable (Traversable(..))
 import Data.Monoid
 #endif
 import Data.Foldable (Foldable(..))
+#ifdef MIN_VERSION_deepseq
+import Control.DeepSeq (NFData(..))
+#endif
 import Control.Monad (liftM)
 #if __GLASGOW_HASKELL__ >= 709
 import Data.Bifunctor
@@ -74,6 +77,9 @@ import GHC.Generics (Generic1)
 --
 -- Moreover, you don't have to rely on the compiler to inline away the extra
 -- argument, because the newtype is \"free\"
+--
+-- 'Tagged' has kind @k -> * -> *@ if the compiler supports @PolyKinds@, therefore
+-- there is an extra @k@ showing in the instance haddocks that may cause confusion.
 newtype Tagged s b = Tagged { unTagged :: b } deriving
   ( Eq, Ord, Ix, Bounded
 #if __GLASGOW_HASKELL__ >= 702
@@ -146,6 +152,11 @@ instance Bifunctor Tagged where
     {-# INLINE bimap #-}
 #endif
 
+#ifdef MIN_VERSION_deepseq
+instance NFData b => NFData (Tagged s b) where
+    rnf (Tagged b) = rnf b
+#endif
+
 instance Applicative (Tagged s) where
     pure = Tagged
     {-# INLINE pure #-}
